@@ -60,39 +60,6 @@ class project {
         }
     }
 
-    /**
-     * Imports a project from Basecamp into Collabtive
-     *
-     * @param string $name Name of the project
-     * @param string $desc Description of the project
-     * @param string $start Date on which the project was started
-     * @param int $status Status of the project
-     * @return int $insid ID des neu angelegten Projekts
-     */
-    function AddFromBasecamp($name, $desc, $start, $status = 1)
-    {
-        global $conn;
-        $id = (int) $id;
-        $status = (int) $status;
-
-        $start = strtotime($start);
-        $tod = date("d.m.Y");
-        $now = strtotime($tod . " +1week");
-
-        $ins1Stmt = $conn->prepare("INSERT INTO projekte (`name`, `desc`,`end`, `start`, `status`) VALUES (?, ?, ?, ?, ?)");
-        $ins1 = $ins1Stmt->execute(array($name, $desc, $now, $start, $status));
-
-        $insid = $conn->lastInsertId();
-
-        if ($ins1) {
-            mkdir(CL_ROOT . "/files/" . CL_CONFIG . "/$insid/", 0777);
-            $this->mylog->add($name, 'projekt', 1, $insid);
-            return $insid;
-        } else {
-            return false;
-        }
-    }
-
     /**
      * Bearbeitet ein Projekt
      *
@@ -155,6 +122,7 @@ class project {
         $del_tasklists = $conn->query("DELETE FROM tasklist WHERE project = $id");
         $del_tasks = $conn->query("DELETE FROM tasks WHERE project = $id");
         $del_timetracker = $conn->query("DELETE FROM timetracker WHERE project = $id");
+    	$del_customer = $conn->query("DELETE FROM customers_assigned WHERE project = $id");
 
         $del_logentries = $conn->query("DELETE FROM log WHERE project = $id");
         $del = $conn->query("DELETE FROM projekte WHERE ID = $id");
@@ -332,7 +300,7 @@ class project {
             if ($project["end"]) {
                 $daysleft = $this->getDaysLeft($project["end"]);
                 $project["daysleft"] = $daysleft;
-                $endstring = date("d.m.Y", $project["end"]);
+                $endstring = date(CL_DATEFORMAT, $project["end"]);
                 $project["endstring"] = $endstring;
             } else {
                 $project["daysleft"] = "";
@@ -345,6 +313,9 @@ class project {
             $project["desc"] = stripslashes($project["desc"]);
             $project["done"] = $this->getProgress($project["ID"]);
 
+        	$companyObj = new company();
+        	$project["customer"] = $companyObj->getProjectCompany($id);
+
             return $project;
         } else {
             return false;
